1.0.0 (2016-02-25)
------------------

Fixes:

- Moved translation to plone.app.locales
  [staeff]

- Fixed install_requires to specify correct dependencies.
  [gforcada]


1.0a1 (2014-04-17)
------------------

- Initial release.
  [ianderso,davisagli,frapell]
